# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class SensitiveCategoryEnum(str, Enum):
    """
    This is the enum that is use to describe the category of our Sensitive Model.
    """

    """
    allowed enum values
    """
    SECRET = 'SECRET'
    API_KEY = 'API_KEY'
    CLIENT_ID = 'CLIENT_ID'
    CLIENT_SECRET = 'CLIENT_SECRET'
    SECRET_KEY = 'SECRET_KEY'
    API_TOKEN = 'API_TOKEN'
    ACCESS_KEY = 'ACCESS_KEY'
    ACCESS_TOKEN = 'ACCESS_TOKEN'
    URL = 'URL'
    PUBLIC_KEY = 'PUBLIC_KEY'
    PRIVATE_KEY = 'PRIVATE_KEY'
    API_ID = 'API_ID'
    WEB_HOOK_URL = 'WEB_HOOK_URL'

    @classmethod
    def from_json(cls, json_str: str) -> SensitiveCategoryEnum:
        """Create an instance of SensitiveCategoryEnum from a JSON string"""
        return SensitiveCategoryEnum(json.loads(json_str))


