# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class OSDeviceRAMTypeEnum(str, Enum):
    """
    ddr3, ddr4, ddr5, gddr6 : this is the type of the RAM
    """

    """
    allowed enum values
    """
    DDR2 = 'DDR2'
    DDR3 = 'DDR3'
    DDR4 = 'DDR4'
    DDR5 = 'DDR5'
    GDDR6 = 'GDDR6'

    @classmethod
    def from_json(cls, json_str: str) -> OSDeviceRAMTypeEnum:
        """Create an instance of OSDeviceRAMTypeEnum from a JSON string"""
        return OSDeviceRAMTypeEnum(json.loads(json_str))


