# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class OSAppletEnum(str, Enum):
    """
    This is an enum specifically for the different types of micro_applications/experiences/feature module  NOTE: TODO copilot_wasm or copilot_minimal NOTE: WORKSTREAM_ACTIVITY and WORKFLOW_ACTIVITY might be diff in the future(workflow is what we have today, workstream will be a v2) NOTE: PLACEHOLDERS here are here to buy some additional changes for enums that dont yet exist(JIC) if not used, then not used.
    """

    """
    allowed enum values
    """
    COPILOT = 'COPILOT'
    PIECES_OS_TOOLBAR = 'PIECES_OS_TOOLBAR'
    WORKSTREAM_SUGGESTIONS = 'WORKSTREAM_SUGGESTIONS'
    SAVED_MATERIALS = 'SAVED_MATERIALS'
    WORKFLOW_ACTIVITY = 'WORKFLOW_ACTIVITY'
    WORKSTREAM_ACTIVITY = 'WORKSTREAM_ACTIVITY'
    GLOBAL_SEARCH = 'GLOBAL_SEARCH'
    PIECES_SUITE_SETTINGS_AND_INTEGRATIONS_MANAGER = 'PIECES_SUITE_SETTINGS_AND_INTEGRATIONS_MANAGER'
    CAPTURED_CONTEXT = 'CAPTURED_CONTEXT'
    UPDATES_AND_UPCOMING = 'UPDATES_AND_UPCOMING'
    NOTIFICATIONS_MANAGER = 'NOTIFICATIONS_MANAGER'
    SHAREBLE_LINK_VIEWER = 'SHAREBLE_LINK_VIEWER'
    FUTURE_APPLET_MODULE_PLACEHOLDER_A = 'FUTURE_APPLET_MODULE_PLACEHOLDER_A'
    FUTURE_APPLET_MODULE_PLACEHOLDER_B = 'FUTURE_APPLET_MODULE_PLACEHOLDER_B'
    FUTURE_APPLET_MODULE_PLACEHOLDER_C = 'FUTURE_APPLET_MODULE_PLACEHOLDER_C'
    UNKNOWN_APPLET_MODULE = 'UNKNOWN_APPLET_MODULE'

    @classmethod
    def from_json(cls, json_str: str) -> OSAppletEnum:
        """Create an instance of OSAppletEnum from a JSON string"""
        return OSAppletEnum(json.loads(json_str))


